==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/regions/ks.php <==
<?php

return [
    'Names' => [
        'AD' => 'اؠنڑورا',
        'AE' => 'مُتحدہ عرَب امارات',
        'AF' => 'اَفغانَستان',
        'AG' => 'اؠنٹِگُوا تہٕ باربوڑا',
        'AI' => 'انگوئیلا',
        'AL' => 'اؠلبانِیا',
        'AM' => 'اَرمانِیا',
        'AO' => 'انگولا',
        'AQ' => 'اینٹارٹِکا',
        'AR' => 'أرجَنٹینا',
        'AS' => 'اَمریٖکَن سَموا',
        'AT' => 'آسٹِیا',
        'AU' => 'آسٹریلِیا',
        'AW' => 'اَروٗبا',
        'AX' => 'ایلینڑ جٔزیٖرٕ',
        'AZ' => 'آزَرباجان',
        'BA' => 'بوسنِیا تہٕ ہَرزِگووِنا',
        'BB' => 'باربیڈاس',
        'BD' => 'بَنگلادیش',
        'BE' => 'بیلجِیَم',
        'BF' => 'بُرکِنا فیسو',
        'BG' => 'بَلجیرِیا',
        'BH' => 'بحریٖن',
        'BI' => 'بورَنڈِ',
        'BJ' => 'بِنِن',
        'BL' => 'سینٹ بارتَھیلمی',
        'BM' => 'بٔرمیوڈا',
        'BN' => 'بُرنٔے',
        'BO' => 'بولِوِیا',
        'BQ' => 'برطانوی قُطبہِ جَنوٗبی علاقہٕ',
        'BR' => 'برازِل',
        'BS' => 'بَہامَس',
        'BT' => 'بوٗٹان',
        'BV' => 'بووَٹ جٔزیٖرٕ',
        'BW' => 'بوتَسوانا',
        'BY' => 'بیلاروٗس',
        'BZ' => 'بیلِج',
        'CA' => 'کینَڑا',
        'CC' => 'کوکَس کیٖلِنگ جٔزیٖرٕ',
        'CD' => 'کونگو کِنشاسا',
        'CF' => 'مرکٔزی اَفریٖکی جموٗریَت',
        'CG' => 'کونگو بٔرزاوِلی',
        'CH' => 'سُوِزَرلینڑ',
        'CI' => 'اَیوٕری کوسٹ',
        'CK' => 'کُک جٔزیٖرٕ',
        'CL' => 'چِلی',
        'CM' => 'کیمِروٗن',
        'CN' => 'چیٖن',
        'CO' => 'کولَمبِیا',
        'CR' => 'کوسٹا رِکا',
        'CU' => 'کیوٗبا',
        'CV' => 'کیپ ؤرڑی',
        'CX' => 'کرِسمَس جٔزیٖرٕ',
        'CY' => 'سایفرس',
        'CZ' => 'چیک جَموٗرِیَت',
        'DE' => 'جرمٔنی',
        'DJ' => 'جِبوٗتی',
        'DK' => 'ڈینمارٕک',
        'DM' => 'ڈومِنِکا',
        'DO' => 'ڈومِنِکَن جموٗرِیَت',
        'DZ' => 'اؠلجیرِیا',
        'EC' => 'اِکواڑور',
        'EE' => 'ایسٹونِیا',
        'EG' => 'مِسٔر',
        'EH' => 'مشرِقی سَہارا',
        'ER' => 'اِرٕٹِیا',
        'ES' => 'سٕپین',
        'ET' => 'اِتھوپِیا',
        'FI' => 'فِنلینڑ',
        'FJ' => 'فِجی',
        'FK' => 'فٕلاکلینڑ جٔزیٖرٕ',
        'FR' => 'فرانس',
        'GA' => 'گیبان',
        'GB' => 'یُنایٹِڑ کِنگڈَم',
        'GD' => 'گرنیڑا',
        'GE' => 'جارجِیا',
        'GF' => 'فرانسِسی گِانا',
        'GG' => 'گیوَنَرسے',
        'GH' => 'گانا',
        'GI' => 'جِبرالٹَر',
        'GL' => 'گریٖنلینڑ',
        'GM' => 'گَمبِیا',
        'GN' => 'گِنی',
        'GP' => 'گَواڑیلوپ',
        'GQ' => 'اِکوِٹورِیَل گِنی',
        'GR' => 'گریٖس',
        'GS' => 'جنوٗبی جارجِیا تہٕ جنوٗبی سینڑوٕچ جٔزیٖرٕ',
        'GT' => 'گوتیدالا',
        'GU' => 'گُوام',
        'GW' => 'گیٖنی بِساو',
        'GY' => 'گُیانا',
        'HK' => 'ہانگ کانگ ایس اے آر چیٖن',
        'HM' => 'ہَرٕڑ جٔزیٖرٕ تہٕ مؠکڈونالڑٕ جٔزیٖرٕ',
        'HN' => 'ہانڈوٗرِس',
        'HR' => 'کروشِیا',
        'HT' => 'ہایتی',
        'HU' => 'ہَنگری',
        'ID' => 'اِنڑونیشِیا',
        'IE' => 'اَیَرلینڑ',
        'IL' => 'اِسرایٖل',
        'IM' => 'آیِل آف مین',
        'IN' => 'ہِندوستان',
        'IO' => 'برطانوی بحرِ ہِندۍ علاقہٕ',
        'IQ' => 'ایٖراق',
        'IR' => 'ایٖران',
        'IS' => 'اَیِسلینڑ',
        'IT' => 'اِٹلی',
        'JE' => 'جٔرسی',
        'JM' => 'جَمایکا',
        'JP' => 'جاپان',
        'KE' => 'کِنیا',
        'KG' => 'کِرگِستان',
        'KH' => 'کَمبوڑِیا',
        'KI' => 'کِرٕباتی',
        'KM' => 'کَمورَس',
        'KN' => 'سینٹ کِٹَس تہٕ نیوِس',
        'KP' => 'شُمٲلی کورِیا',
        'KR' => 'جنوٗبی کورِیا',
        'KW' => 'کُویت',
        'KY' => 'کیمَن جٔزیٖرٕ',
        'KZ' => 'کَزاکِستان',
        'LA' => 'لاس',
        'LB' => 'لؠبنان',
        'LC' => 'سینٹ لوٗسِیا',
        'LI' => 'لِکٹیسٹیٖن',
        'LK' => 'سِریٖلَنکا',
        'LR' => 'لایبیرِیا',
        'LS' => 'لیسوتھو',
        'LT' => 'لِتھُوانِیا',
        'LU' => 'لَکسَمبٔرٕگ',
        'LV' => 'لیٹوِیا',
        'LY' => 'لِبیا',
        'MA' => 'موروکو',
        'MC' => 'مونیکو',
        'MD' => 'مولڑاوِیا',
        'ME' => 'موٹونیگِریو',
        'MF' => 'سینٹ مارٹِن',
        'MG' => 'میڑاگاسکار',
        'MH' => 'مارشَل جٔزیٖرٕ',
        'ML' => 'مالی',
        'MM' => 'مَیَنما بٔرما',
        'MN' => 'مَنگولِیا',
        'MO' => 'مَکاوو ایس اے آر چیٖن',
        'MP' => 'شُمٲلی مارِیانا جٔزیٖرٕ',
        'MQ' => 'مارٹِنِک',
        'MR' => 'مارٕٹانِیا',
        'MS' => 'مانٹسیراٹ',
        'MT' => 'مالٹا',
        'MU' => 'مورِشَس',
        'MV' => 'مالدیٖو',
        'MW' => 'ملاوی',
        'MX' => 'مؠکسِکو',
        'MY' => 'مَلیشِیا',
        'MZ' => 'موزَمبِک',
        'NA' => 'نامِبِیا',
        'NC' => 'نِو کیلِڑونِیا',
        'NE' => 'نایجَر',
        'NF' => 'نارفاک جٔزیٖرٕ',
        'NG' => 'نایجیرِیا',
        'NI' => 'ناکاراگُوا',
        'NL' => 'نیٖدَرلینڑ',
        'NO' => 'ناروے',
        'NP' => 'نیپال',
        'NR' => 'نارووٗ',
        'NU' => 'نیوٗ',
        'NZ' => 'نیوٗزِلینڑ',
        'OM' => 'اومان',
        'PA' => 'پَناما',
        'PE' => 'پیٖروٗ',
        'PF' => 'فرانسی پولِنیشِیا',
        'PG' => 'پاپُوا نیوٗ گیٖنی',
        'PH' => 'فِلِپِینس',
        'PK' => 'پاکِستان',
        'PL' => 'پولینڑ',
        'PM' => 'سینٹ پیٖری تہٕ موکیلِیَن',
        'PN' => 'پِٹکیرٕنۍ جٔزیٖرٕ',
        'PR' => 'پٔرٹو رِکو',
        'PS' => 'فَلَستیٖن',
        'PT' => 'پُرتِگال',
        'PW' => 'پَلاو',
        'PY' => 'پَراگُے',
        'QA' => 'قَطِر',
        'RE' => 'رِیوٗنِیَن',
        'RO' => 'رومانِیا',
        'RS' => 'سَربِیا',
        'RU' => 'روٗس',
        'RW' => 'روٗوانڈا',
        'SA' => 'سوٗدی عربِیہ',
        'SB' => 'سولامان جٔزیٖرٕ',
        'SC' => 'سیشَلِس',
        'SD' => 'سوٗڈان',
        'SE' => 'سُوِڈَن',
        'SG' => 'سِنگاپوٗر',
        'SH' => 'سینٹ ہؠلِنا',
        'SI' => 'سَلووینِیا',
        'SJ' => 'سَوالبریڑ تہٕ جان ماییڑ',
        'SK' => 'سَلوواکِیا',
        'SL' => 'سیٖرالیوون',
        'SM' => 'سین میرِنو',
        'SN' => 'سینیگَل',
        'SO' => 'سومالِیا',
        'SR' => 'سُرِنام',
        'ST' => 'ساو توم تہٕ پرنسِپی',
        'SV' => 'اؠل سَلواڑور',
        'SY' => 'شام',
        'SZ' => 'سُوزِلینڑ',
        'TC' => 'تُرُک تہٕ کیکوس جٔزیٖرٕ',
        'TD' => 'چاڑ',
        'TF' => 'فرانسِسی جَنوٗبی عَلاقہٕ',
        'TG' => 'ٹوگو',
        'TH' => 'تھایلینڑ',
        'TJ' => 'تاجکِستان',
        'TK' => 'توکیلاو',
        'TL' => 'مَشرِقی تایمور',
        'TM' => 'تُرمِنِستان',
        'TN' => 'ٹونیشِیا',
        'TO' => 'ٹونگا',
        'TR' => 'تُرکی',
        'TT' => 'ٹرنِنداد تہٕ ٹوبیگو',
        'TV' => 'توٗوالوٗ',
        'TW' => 'تایوان',
        'TZ' => 'تَنجانِیا',
        'UA' => 'یوٗرِکین',
        'UG' => 'یوٗگانڑا',
        'UM' => 'یوٗنایٹِڑ سِٹیٹِس ماینَر آوُٹلییِنگ جٔزیٖرٕ',
        'US' => 'یوٗنایٹِڑ سِٹیٹِس',
        'UY' => 'یوٗروگے',
        'UZ' => 'اُزبِکِستان',
        'VA' => 'ویٹِکَن سِٹی',
        'VC' => 'سینٹ وینسؠٹ تہٕ گریناڑاینٕز',
        'VE' => 'وینازوٗلا',
        'VG' => 'بَرطانوی ؤرجِن جٔزیٖرٕ',
        'VI' => 'یوٗ ایس ؤرجِن جٔزیٖرٕ',
        'VN' => 'ویٹِنام',
        'VU' => 'وانوٗتوٗ',
        'WF' => 'والِس تہٕ فیوٗچوٗنا',
        'WS' => 'سیمووا',
        'YE' => 'یَمَن',
        'YT' => 'مَییٹ',
        'ZA' => 'جَنوٗبی اَفریٖکا',
        'ZM' => 'جامبِیا',
        'ZW' => 'زِمبابے',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/regions/ks.php <==
<?php

return [
    'Names' => [
        'AD' => 'اینڈورا',
        'AE' => 'مُتحدہ عرَب امارات',
        'AF' => 'اَفغانَستان',
        'AG' => 'اؠنٹِگُوا تہٕ باربوڑا',
        'AI' => 'انگوئیلا',
        'AL' => 'البانیا',
        'AM' => 'اَرمانِیا',
        'AO' => 'انگولا',
        'AQ' => 'اینٹارٹِکا',
        'AR' => 'أرجَنٹینا',
        'AS' => 'اَمریٖکَن سَموا',
        'AT' => 'آسٹریا',
        'AU' => 'آسٹریلِیا',
        'AW' => 'اَروٗبا',
        'AX' => 'ایلینڑ جٔزیٖرٕ',
        'AZ' => 'آذربائیجان',
        'BA' => 'بوسنِیا تہٕ ہَرزِگووِنا',
        'BB' => 'باربیڈوس',
        'BD' => 'بَنگلادیش',
        'BE' => 'بیلجِیَم',
        'BF' => 'بُرکِنا فیسو',
        'BG' => 'بَلجیرِیا',
        'BH' => 'بحریٖن',
        'BI' => 'بورَنڈِ',
        'BJ' => 'بِنِن',
        'BL' => 'سینٹ بارتَھیلمی',
        'BM' => 'برمودا',
        'BN' => 'برونے',
        'BO' => 'بولِوِیا',
        'BQ' => 'کیریبین نیدرلینڈس',
        'BR' => 'برازِل',
        'BS' => 'بَہامَس',
        'BT' => 'بوٗٹان',
        'BV' => 'بووَٹ جٔزیٖرٕ',
        'BW' => 'بوتَسوانا',
        'BY' => 'بیلاروٗس',
        'BZ' => 'بیلز',
        'CA' => 'کینیڈا',
        'CC' => 'کوکَس (کیٖلِنگ) جٔزیٖرٕ',
        'CD' => 'کونگو کِنشاسا',
        'CF' => 'مرکٔزی اَفریٖکی جموٗریَت',
        'CG' => 'کونگو بٔرزاوِلی',
        'CH' => 'سُوِزَرلینڑ',
        'CI' => 'کوٹ ڈلوائر',
        'CK' => 'کُک جٔزیٖرٕ',
        'CL' => 'چِلی',
        'CM' => 'کیمِروٗن',
        'CN' => 'چیٖن',
        'CO' => 'کولَمبِیا',
        'CR' => 'کوسٹا ریکا',
        'CU' => 'کیوٗبا',
        'CV' => 'کیپ ؤرڑی',
        'CW' => 'کیوراکو',
        'CX' => 'کرِسمَس جٔزیٖرٕ',
        'CY' => 'سائپرس',
        'CZ' => 'چیکیا',
        'DE' => 'جرمٔنی',
        'DJ' => 'جِبوٗتی',
        'DK' => 'ڈینمارٕک',
        'DM' => 'ڈومِنِکا',
        'DO' => 'ڈومِنِکَن جموٗرِیَت',
        'DZ' => 'اؠلجیرِیا',
        'EC' => 'اِکواڑور',
        'EE' => 'ایسٹونِیا',
        'EG' => 'مصر',
        'EH' => 'مشرِقی سَہارا',
        'ER' => 'اِرٕٹِیا',
        'ES' => 'سٕپین',
        'ET' => 'اِتھوپِیا',
        'FI' => 'فِن لینڈ',
        'FJ' => 'فِجی',
        'FK' => 'فٕلاکلینڑ جٔزیٖرٕ',
        'FM' => 'مائیکرونیشیا',
        'FO' => 'فارو جزیرہ',
        'FR' => 'فرانس',
        'GA' => 'گیبان',
        'GB' => 'متحدہ مملِکت',
        'GD' => 'گرینیڈا',
        'GE' => 'جارجِیا',
        'GF' => 'فرانسِسی گِانا',
        'GG' => 'گورنسے',
        'GH' => 'گانا',
        'GI' => 'جِبرالٹَر',
        'GL' => 'گرین لینڈ',
        'GM' => 'گَمبِیا',
        'GN' => 'گِنی',
        'GP' => 'گواڈلوپ',
        'GQ' => 'اِکوِٹورِیَل گِنی',
        'GR' => 'گریٖس',
        'GS' => 'جنوٗبی جارجِیا تہٕ جنوٗبی سینڑوٕچ جٔزیٖرٕ',
        'GT' => 'گواٹمالا',
        'GU' => 'گُوام',
        'GW' => 'گیٖنی بِساو',
        'GY' => 'گُیانا',
        'HK' => 'ہانگ کانگ ایس اے آر چیٖن',
        'HM' => 'ہَرٕڑ تہٕ مؠکڈونالڑٕ جٔزیٖرٕ',
        'HN' => 'ہونڈورس',
        'HR' => 'کروشِیا',
        'HT' => 'ہیتی',
        'HU' => 'ہَنگری',
        'ID' => 'انڈونیشیا',
        'IE' => 'اَیَرلینڑ',
        'IL' => 'اسرا ییل',
        'IM' => 'آیِل آف مین',
        'IN' => 'ہِندوستان',
        'IO' => 'برطانوی بحرِ ہِندۍ علاقہٕ',
        'IQ' => 'ایٖراق',
        'IR' => 'ایٖران',
        'IS' => 'اَیِسلینڑ',
        'IT' => 'اِٹلی',
        'JE' => 'جٔرسی',
        'JM' => 'جَمایکا',
        'JO' => 'جورڈن',
        'JP' => 'جاپان',
        'KE' => 'کِنیا',
        'KG' => 'کرغزستان',
        'KH' => 'کَمبوڑِیا',
        'KI' => 'کِرٕباتی',
        'KM' => 'کَمورَس',
        'KN' => 'سینٹ کِٹَس تہٕ نیوِس',
        'KP' => 'شُمٲلی کورِیا',
        'KR' => 'جنوٗبی کورِیا',
        'KW' => 'کُویت',
        'KY' => 'کیمَن جٔزیٖرٕ',
        'KZ' => 'قازقستان',
        'LA' => 'لاس',
        'LB' => 'لؠبنان',
        'LC' => 'سینٹ لوٗسِیا',
        'LI' => 'لِکٹیسٹیٖن',
        'LK' => 'سری لنکا',
        'LR' => 'لایبیرِیا',
        'LS' => 'لیسوتھو',
        'LT' => 'لِتھُوانِیا',
        'LU' => 'لَکسَمبٔرٕگ',
        'LV' => 'لیٹوِیا',
        'LY' => 'لِبیا',
        'MA' => 'موروکو',
        'MC' => 'مونیکو',
        'MD' => 'مولڈووا',
        'ME' => 'موٹونیگِریو',
        'MF' => 'سینٹ مارٹِن',
        'MG' => 'میڈاگاسکار',
        'MH' => 'مارشَل جٔزیٖرٕ',
        'MK' => 'شُمالی میسڈونیا',
        'ML' => 'مالی',
        'MM' => 'میانمار (برما)',
        'MN' => 'مَنگولِیا',
        'MO' => 'مَکاوو ایس اے آر چیٖن',
        'MP' => 'شُمٲلی مارِیانا جٔزیٖرٕ',
        'MQ' => 'مارٹِنِک',
        'MR' => 'مارٕٹانِیا',
        'MS' => 'مانٹسیراٹ',
        'MT' => 'مالٹا',
        'MU' => 'مورِشَس',
        'MV' => 'مالدیٖو',
        'MW' => 'ملاوی',
        'MX' => 'مؠکسِکو',
        'MY' => 'مَلیشِیا',
        'MZ' => 'موزَمبِک',
        'NA' => 'نامِبِیا',
        'NC' => 'نِو کیلِڑونِیا',
        'NE' => 'نایجَر',
        'NF' => 'نارفاک جٔزیٖرٕ',
        'NG' => 'نایجیرِیا',
        'NI' => 'ناکاراگُوا',
        'NL' => 'نیٖدَرلینڑ',
        'NO' => 'ناروے',
        'NP' => 'نیپال',
        'NR' => 'نارووٗ',
        'NU' => 'نیوٗ',
        'NZ' => 'نیوزی لینڈ',
        'OM' => 'اومان',
        'PA' => 'پَناما',
        'PE' => 'پیٖروٗ',
        'PF' => 'فرانسی پولِنیشِیا',
        'PG' => 'پاپُوا نیوٗ گیٖنی',
        'PH' => 'فلپائن',
        'PK' => 'پاکِستان',
        'PL' => 'پولینڈ',
        'PM' => 'سینٹ پیٖری تہٕ موکیلِیَن',
        'PN' => 'پِٹکیرٕنۍ جٔزیٖرٕ',
        'PR' => 'پٔرٹو رِکو',
        'PS' => 'فلسطینی علاقٕہ',
        'PT' => 'پُرتِگال',
        'PW' => 'پَلاو',
        'PY' => 'پَراگُے',
        'QA' => 'قَطِر',
        'RE' => 'رِیوٗنِیَن',
        'RO' => 'رومانِیا',
        'RS' => 'سَربِیا',
        'RU' => 'روٗس',
        'RW' => 'روٗوانڈا',
        'SA' => 'سعودی عرب',
        'SB' => 'سولامان جٔزیٖرٕ',
        'SC' => 'سیشَلِس',
        'SD' => 'سوٗڈان',
        'SE' => 'سویڈن',
        'SG' => 'سِنگاپوٗر',
        'SH' => 'سینٹ ہؠلِنا',
        'SI' => 'سَلووینِیا',
        'SJ' => 'سَوالبریڑ تہٕ جان ماییڑ',
        'SK' => 'سَلوواکِیا',
        'SL' => 'سیرا لیون',
        'SM' => 'سین میرِنو',
        'SN' => 'سینیگَل',
        'SO' => 'سومالِیا',
        'SR' => 'سُرِنام',
        'SS' => 'جنوبی سوڈان',
        'ST' => 'ساو توم تہٕ پرنسِپی',
        'SV' => 'ایل سلویڈر',
        'SX' => 'سِنٹ مارٹِن',
        'SY' => 'شام',
        'SZ' => 'ایسواتنی',
        'TC' => 'تُرکس تٕہ کیکو جزیرٕ',
        'TD' => 'چاڑ',
        'TF' => 'فرانسِسی جَنوٗبی عَلاقہٕ',
        'TG' => 'ٹوگو',
        'TH' => 'تھائی لینڈ',
        'TJ' => 'تاجکِستان',
        'TK' => 'ٹوکلو',
        'TL' => 'تیمور-لیسٹ',
        'TM' => 'تُرکمنستان',
        'TN' => 'ٹونیشِیا',
        'TO' => 'ٹونگا',
        'TR' => 'تُرکی',
        'TT' => 'ٹرنِنداد تہٕ ٹوبیگو',
        'TV' => 'توٗوالوٗ',
        'TW' => 'تایوان',
        'TZ' => 'تَنجانِیا',
        'UA' => 'یوٗرِکین',
        'UG' => 'یوٗگانڑا',
        'UM' => 'یوٗنایٹِڑ سِٹیٹِس ماینَر آوُٹلییِنگ جٔزیٖرٕ',
        'US' => 'یوٗنایٹِڑ سِٹیٹِس',
        'UY' => 'یوٗروگے',
        'UZ' => 'اُزبِکِستان',
        'VA' => 'ویٹِکَن سِٹی',
        'VC' => 'سینٹ وینسؠٹ تہٕ گریناڑاینٕز',
        'VE' => 'وینازوٗلا',
        'VG' => 'بَرطانوی ؤرجِن جٔزیٖرٕ',
        'VI' => 'یوٗ ایس ؤرجِن جٔزیٖرٕ',
        'VN' => 'ویتنام',
        'VU' => 'وانوٗتوٗ',
        'WF' => 'والِس تہٕ فیوٗچوٗنا',
        'WS' => 'سامو',
        'YE' => 'یَمَن',
        'YT' => 'مَییٹ',
        'ZA' => 'جنوبی افریقہ',
        'ZM' => 'زیمبیا',
        'ZW' => 'زِمبابے',
    ],
];
